@@ -23,12 +23,12 @@ class BindEntry(t.Struct):
     clusterIdList: t.ClusterIdList
 
 
-class AgingEndDevice(t.Struct):
+class AgingEndDevice(t.CStruct):
     endDevCfg: t.uint8_t
     deviceTimeout: t.uint32_t
 
 
-class LinkInfo(t.Struct):
+class LinkInfo(t.CStruct):
     txCounter: t.uint8_t  # Counter of transmission success/failures
     txCost: t.uint8_t  # Average of sending rssi values if link staus is enabled
     #   i.e. NWK_LINK_STATUS_PERIOD is defined as non zero
@@ -39,7 +39,7 @@ class LinkInfo(t.Struct):
     txFailure: t.uint16_t  # higher values indicate more failures
 
 
-class Device(t.Struct):
+class Device(t.CStruct):
     shortAddr: t.NWK
     addrIdx: t.uint16_t
     nodeRelation: NodeRelation
@@ -47,22 +47,10 @@ class Device(t.Struct):
     assocCnt: t.uint8_t
     age: t.uint8_t
     linkInfo: LinkInfo
-
-    PaddingByte1: t.PaddingByte
-    PaddingByte2: t.PaddingByte
-
     endDev: AgingEndDevice
-
-    PaddingByte3: t.PaddingByte
-    PaddingByte4: t.PaddingByte
-    PaddingByte5: t.PaddingByte
-
     timeoutCounter: t.uint32_t
     keepaliveRcv: t.uint8_t  # not a bool, can be 0xFF
-    ctrl: t.uint8_t
-
-    PaddingByte6: t.PaddingByte
-    PaddingByte7: t.PaddingByte
+    ctrl: t.uint8_t  # XXX: This field is only present in Z-Stack 3.30+ !!!
 
 
 class Key(t.FixedList, item_type=t.uint8_t, length=42):
@@ -81,7 +69,7 @@ class LEDMode(t.enum_uint8):
     TOGGLE = 4
 
 
-class Util(t.CommandsBase, subsystem=t.Subsystem.UTIL):
+class UTIL(t.CommandsBase, subsystem=t.Subsystem.UTIL):
     # MAC Reset command to reset MAC state machine
     GetDeviceInfo = t.CommandDef(
         t.CommandType.SREQ,
@@ -391,11 +379,11 @@ class Util(t.CommandsBase, subsystem=t.Subsystem.UTIL):
         0x48,
         req_schema=(
             t.Param(
-                "StartRelation", t.uint8_t, "A valid node relation from AssocList.h"
+                "StartRelation", NodeRelation, "A valid node relation from AssocList.h"
             ),
             t.Param(
                 "EndRelation",
-                t.uint8_t,
+                NodeRelation,
                 "Same as StartRelation, but the node relation to stop counting",
             ),
         ),
@@ -436,7 +424,7 @@ class Util(t.CommandsBase, subsystem=t.Subsystem.UTIL):
 
     # send a request key to the Trust Center from an originator device who wants to
     # exchange messages with a partner device
-    APSMEREquestKeyCmd = t.CommandDef(
+    APSMERequestKeyCmd = t.CommandDef(
         t.CommandType.SREQ,
         0x4B,
         req_schema=(
