@@ -1,28 +1,18 @@
 import sys
 import asyncio
 import logging
-import argparse
 
 import async_timeout
 
 import zigpy_znp.commands as c
 from zigpy_znp.api import ZNP
 from zigpy_znp.config import CONFIG_SCHEMA
-from zigpy_znp.tools.common import setup_parser
+from zigpy_znp.tools.common import ClosableFileType, setup_parser
 
 LOGGER = logging.getLogger(__name__)
 
 
-async def read_firmware(radio_path: str) -> bytearray:
-    znp = ZNP(
-        CONFIG_SCHEMA(
-            {"znp_config": {"skip_bootloader": False}, "device": {"path": radio_path}}
-        )
-    )
-
-    # The bootloader handshake must be the very first command
-    await znp.connect(test_port=False)
-
+async def read_firmware(znp: ZNP) -> bytearray:
     try:
         async with async_timeout.timeout(5):
             handshake_rsp = await znp.request_callback_rsp(
@@ -60,8 +50,6 @@ async def read_firmware(radio_path: str) -> bytearray:
 
         data.extend(read_rsp.Data)
 
-    znp.close()
-
     return data
 
 
@@ -70,16 +58,32 @@ async def main(argv):
     parser.add_argument(
         "--output",
         "-o",
-        type=argparse.FileType("wb"),
+        type=ClosableFileType("wb"),
         help="Output .bin file",
         required=True,
     )
 
     args = parser.parse_args(argv)
-    data = await read_firmware(args.serial)
-    args.output.write(data)
 
-    LOGGER.info("Unplug your adapter to leave bootloader mode!")
+    with args.output as f:
+        znp = ZNP(
+            CONFIG_SCHEMA(
+                {
+                    "znp_config": {"skip_bootloader": False},
+                    "device": {"path": args.serial},
+                }
+            )
+        )
+
+        # The bootloader handshake must be the very first command
+        await znp.connect(test_port=False)
+
+        data = await read_firmware(znp)
+        znp.close()
+
+        f.write(data)
+
+        LOGGER.info("Unplug your adapter to leave bootloader mode!")
 
 
 if __name__ == "__main__":
